"""Sidecar utility subpackage — text utils, prompts, and exclusions."""
from cmdop_claude.sidecar.utils.text_utils import normalize_content
from cmdop_claude.sidecar.utils.prompts import (
    REVIEW_SYSTEM,
    REVIEW_USER,
    MAP_SYSTEM,
    MAP_USER,
    FIX_SYSTEM,
    FIX_USER,
    TREE_CHUNK_SYSTEM,
    TREE_CHUNK_USER,
    FILE_SELECT_SYSTEM,
    FILE_SELECT_USER,
    INIT_SYSTEM,
    INIT_USER,
)
from cmdop_claude.sidecar.utils.exclusions import (
    GLOBAL_EXCLUDE_DIRS,
    GLOBAL_EXCLUDE_PATTERNS,
    SENSITIVE_FILES,
    SENSITIVE_CONTENT_RE,
    DirInfo,
    load_gitignore,
    should_exclude_dir,
    should_exclude_file,
    is_sensitive_file,
    is_sensitive_content,
    scan_project_dirs,
)

__all__ = [
    "normalize_content",
    "REVIEW_SYSTEM",
    "REVIEW_USER",
    "MAP_SYSTEM",
    "MAP_USER",
    "FIX_SYSTEM",
    "FIX_USER",
    "TREE_CHUNK_SYSTEM",
    "TREE_CHUNK_USER",
    "FILE_SELECT_SYSTEM",
    "FILE_SELECT_USER",
    "INIT_SYSTEM",
    "INIT_USER",
    "GLOBAL_EXCLUDE_DIRS",
    "GLOBAL_EXCLUDE_PATTERNS",
    "SENSITIVE_FILES",
    "SENSITIVE_CONTENT_RE",
    "DirInfo",
    "load_gitignore",
    "should_exclude_dir",
    "should_exclude_file",
    "is_sensitive_file",
    "is_sensitive_content",
    "scan_project_dirs",
]
